# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_ityp.ipynb.

# %% auto 0
__all__ = ['IterStr', 'IterNum', 'IterBool']

# %% ../nbs/03_ityp.ipynb 4
from typing import (
    Type, TypeAlias, 
    ClassVar, Any, Optional, Callable, Iterable, 
)
from numbers import Number

# %% ../nbs/03_ityp.ipynb 5
from .atyp import Boolish, Numeric, StrLike, Module

# %% ../nbs/03_ityp.ipynb 7
IterStr: TypeAlias = Iterable[str]
IterNum: TypeAlias = Iterable[Numeric]
IterBool: TypeAlias = Iterable[Boolish]
