# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.atyp': { 'atyp.atyp.ATyp': ('atyp.html#atyp', 'atyp/atyp.py'),
                           'atyp.atyp.Alias': ('atyp.html#alias', 'atyp/atyp.py'),
                           'atyp.atyp.Alias.__init_subclass__': ('atyp.html#alias.__init_subclass__', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta': ('atyp.html#aliasmeta', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.__call__': ('atyp.html#aliasmeta.__call__', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.__instancecheck__': ('atyp.html#aliasmeta.__instancecheck__', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.__new__': ('atyp.html#aliasmeta.__new__', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.check': ('atyp.html#aliasmeta.check', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.default_kwds': ('atyp.html#aliasmeta.default_kwds', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.getclsname': ('atyp.html#aliasmeta.getclsname', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.getqualname': ('atyp.html#aliasmeta.getqualname', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.setattrs': ('atyp.html#aliasmeta.setattrs', 'atyp/atyp.py'),
                           'atyp.atyp.AliasMeta.settypes': ('atyp.html#aliasmeta.settypes', 'atyp/atyp.py'),
                           'atyp.atyp.aliascheck': ('atyp.html#aliascheck', 'atyp/atyp.py'),
                           'atyp.atyp.eqliteral': ('atyp.html#eqliteral', 'atyp/atyp.py'),
                           'atyp.atyp.isliteral': ('atyp.html#isliteral', 'atyp/atyp.py')},
            'atyp.biol': {},
            'atyp.bool': {'atyp.bool.Bool01': ('bool.html#bool01', 'atyp/bool.py')},
            'atyp.btyp': {},
            'atyp.byte': {},
            'atyp.clsv': {},
            'atyp.cstm': {},
            'atyp.ctyp': {},
            'atyp.data': {},
            'atyp.dtyp': {},
            'atyp.enum': {},
            'atyp.imgs': {},
            'atyp.imps': {},
            'atyp.insp': {},
            'atyp.iter': {},
            'atyp.ityp': {},
            'atyp.list': {},
            'atyp.logr': {},
            'atyp.mtyp': {},
            'atyp.npty': {},
            'atyp.nums': {},
            'atyp.path': {},
            'atyp.pdty': {'atyp.pdty.BoolIndex': ('pdty.html#boolindex', 'atyp/pdty.py')},
            'atyp.plot': {},
            'atyp.ptyp': {},
            'atyp.qtyp': {},
            'atyp.rich': {},
            'atyp.rtyp': {},
            'atyp.sets': {},
            'atyp.spty': {},
            'atyp.strs': {},
            'atyp.tens': {},
            'atyp.tgrd': {},
            'atyp.type': {},
            'atyp.typq': {},
            'atyp.typr': {},
            'atyp.ztyp': {}}}
