# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/06_rtyp.ipynb.

# %% auto 0
__all__ = ['RichTree', 'RichText', 'RichCons', 'RichProg', 'TyperApp']

# %% ../nbs/libs/06_rtyp.ipynb 4
from typing import TypeAlias, ForwardRef

# %% ../nbs/libs/06_rtyp.ipynb 6
try:
    from rich.tree import Tree
    from rich.text import Text
    from rich.console import Console
    from rich.progress import Progress
    tree = Tree
    text = Text
    cons = Console
    prog = Progress
    
except ImportError:
    tree = ForwardRef('rich.tree.Tree', is_class=True)
    text = ForwardRef('rich.text.Text', is_class=True)
    cons = ForwardRef('rich.console.Console', is_class=True)
    prog = ForwardRef('rich.progress.Progress', is_class=True)

# %% ../nbs/libs/06_rtyp.ipynb 7
RichTree: TypeAlias = tree
RichText: TypeAlias = text
RichCons: TypeAlias = cons
RichProg: TypeAlias = prog

# %% ../nbs/libs/06_rtyp.ipynb 9
try:
    from typer import Typer
    tapp = Typer    
except ImportError:
    tapp = ForwardRef('typer.Typer', is_class=True)

# %% ../nbs/libs/06_rtyp.ipynb 10
TyperApp: TypeAlias = tapp
