# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_ztyp.ipynb.

# %% auto 0
__all__ = ['FlagFunc', 'FlagFuncQ', 'PathFormatFunc', 'Mixin']

# %% ../nbs/30_ztyp.ipynb 4
import os
from typing import List, Union, TypeAlias, Callable, Optional, ParamSpec, Type, Callable, Tuple

# %% ../nbs/30_ztyp.ipynb 6
from .atyp import Boolish
from .qtyp import AnyQ, StrQ

# %% ../nbs/30_ztyp.ipynb 7
FlagFunc: TypeAlias = Callable[[AnyQ], Boolish]

FlagFuncQ: TypeAlias = Optional[FlagFunc]

# %% ../nbs/30_ztyp.ipynb 11
PathFormatFunc: TypeAlias = Callable[[os.PathLike, StrQ, StrQ, StrQ], str]

# %% ../nbs/30_ztyp.ipynb 13
Mixin: TypeAlias =  Union[Tuple[Type, Callable], 'MixinType']
